==> ogre-next-2.3.3-3-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/class_ogre_1_1_texture_gpu_manager.js <==
var class_ogre_1_1_texture_gpu_manager =
[
    [ "BudgetEntry", "struct_ogre_1_1_texture_gpu_manager_1_1_budget_entry.html", "struct_ogre_1_1_texture_gpu_manager_1_1_budget_entry" ],
    [ "MetadataCacheEntry", "struct_ogre_1_1_texture_gpu_manager_1_1_metadata_cache_entry.html", "struct_ogre_1_1_texture_gpu_manager_1_1_metadata_cache_entry" ],
    [ "ResourceEntry", "struct_ogre_1_1_texture_gpu_manager_1_1_resource_entry.html", "struct_ogre_1_1_texture_gpu_manager_1_1_resource_entry" ],
    [ "BudgetEntryVec", "class_ogre_1_1_texture_gpu_manager.html#a243112239378b673ba9f1df5e7abdbf3", null ],
    [ "MetadataCacheMap", "class_ogre_1_1_texture_gpu_manager.html#a75e42d75a1eae1a28e52e4613832edb3", null ],
    [ "ResourceEntryMap", "class_ogre_1_1_texture_gpu_manager.html#ad657330e7020f561860d24366460271c", null ],
    [ "Reason", "class_ogre_1_1_texture_gpu_manager.html#afe11bd546cf7315f4526488e7078cc7d", [
      [ "Unknown", "class_ogre_1_1_texture_gpu_manager.html#afe11bd546cf7315f4526488e7078cc7da2b732a317de0915527e291485ca42e82", null ],
      [ "FromStorageToSysRam", "class_ogre_1_1_texture_gpu_manager.html#afe11bd546cf7315f4526488e7078cc7da58fd07194714679ed3ba9857d7656f27", null ],
      [ "FromSysRamToStorage", "class_ogre_1_1_texture_gpu_manager.html#afe11bd546cf7315f4526488e7078cc7da058c0eecb9f3f188fccc4d0018bf337b", null ],
      [ "GainedResidency", "class_ogre_1_1_texture_gpu_manager.html#afe11bd546cf7315f4526488e7078cc7da55066351a26967068b944c2170e51af1", null ],
      [ "LostResidency", "class_ogre_1_1_texture_gpu_manager.html#afe11bd546cf7315f4526488e7078cc7da61729c4ae25807d6132d5bc46580ff3d", null ],
      [ "PoolTextureSlotChanged", "class_ogre_1_1_texture_gpu_manager.html#afe11bd546cf7315f4526488e7078cc7dafbdd85981846de4423d48d1a0ff665e0", null ],
      [ "ResidentToSysRamSync", "class_ogre_1_1_texture_gpu_manager.html#afe11bd546cf7315f4526488e7078cc7da218a4243be85ec9c989b777119d5ff47", null ],
      [ "MetadataCacheOutOfDate", "class_ogre_1_1_texture_gpu_manager.html#afe11bd546cf7315f4526488e7078cc7da4f559ca1853a24a28b40caae1acda604", null ],
      [ "ExceptionThrown", "class_ogre_1_1_texture_gpu_manager.html#afe11bd546cf7315f4526488e7078cc7da704ea118c7e9f0b1598b528bdcbe1b26", null ],
      [ "FsaaSettingAlteredByApi", "class_ogre_1_1_texture_gpu_manager.html#afe11bd546cf7315f4526488e7078cc7dae3eb70053cbf5401f22893cdb47f81a7", null ],
      [ "ReadyForRendering", "class_ogre_1_1_texture_gpu_manager.html#afe11bd546cf7315f4526488e7078cc7dad4d9c6e3b7755f38d8d5f003be100257", null ],
      [ "Deleted", "class_ogre_1_1_texture_gpu_manager.html#afe11bd546cf7315f4526488e7078cc7dabb2a61a0002ccca6afbde7588787e58e", null ]
    ] ],
    [ "TextureGpuManager", "class_ogre_1_1_texture_gpu_manager.html#a7cc799aa12f7b03c686cec13d09d9c0b", null ],
    [ "~TextureGpuManager", "class_ogre_1_1_texture_gpu_manager.html#a4f064af71e447dbdfa846188b27810f6", null ],
    [ "_queueDownloadToRam", "class_ogre_1_1_texture_gpu_manager.html#a68dec5d2c3187c3d7be56d9c5cc55fc4", null ],
    [ "_releaseSlotFromTexture", "class_ogre_1_1_texture_gpu_manager.html#a89a4bb400a24d0e3ea9a9299192fa51d", null ],
    [ "_removeMetadataCacheEntry", "class_ogre_1_1_texture_gpu_manager.html#a38a3edb2437dae48c14a0d20c50877fa", null ],
    [ "_reserveSlotForTexture", "class_ogre_1_1_texture_gpu_manager.html#a93773f33d6018c991b4fa8c475a8a36d", null ],
    [ "_scheduleTransitionTo", "class_ogre_1_1_texture_gpu_manager.html#a435b32507353f22b8428e6f9d849e7e1", null ],
    [ "_scheduleUpdate", "class_ogre_1_1_texture_gpu_manager.html#a46f6c11e4af75070ada1e868e7b24412", null ],
    [ "_setIgnoreScheduledTasks", "class_ogre_1_1_texture_gpu_manager.html#ae905930e6b79e3a3c3152efc20d5249c", null ],
    [ "_update", "class_ogre_1_1_texture_gpu_manager.html#aa961b3aafc08805f7611d4edd283f804", null ],
    [ "_updateMetadataCache", "class_ogre_1_1_texture_gpu_manager.html#a4f6d7560d59263dc303563777b5c61e8", null ],
    [ "_updateStreaming", "class_ogre_1_1_texture_gpu_manager.html#aec3f9567c396b28a1f73a7044d9957bd", null ],
    [ "_updateStreamingWorkerThread", "class_ogre_1_1_texture_gpu_manager.html#a4f6ee50fe51ac71c60f66e044859bf9d", null ],
    [ "_waitFor", "class_ogre_1_1_texture_gpu_manager.html#a2c872d542fd78e2db884ff8904d4c39d", null ],
    [ "_waitForPendingGpuToCpuSyncs", "class_ogre_1_1_texture_gpu_manager.html#ac55e0672860ad3ed3695374d9e12c7ba", null ],
    [ "checkSupport", "class_ogre_1_1_texture_gpu_manager.html#ae4cace3a36dcc63cb0ba5662f2c29b8a", null ],
    [ "createAsyncTextureTicket", "class_ogre_1_1_texture_gpu_manager.html#a71e7ae62f823f48c7c4844a2d34589de", null ],
    [ "createOrRetrieveTexture", "class_ogre_1_1_texture_gpu_manager.html#ad118a876e3102b5ae6ba5cefba5bdf1d", null ],
    [ "createOrRetrieveTexture", "class_ogre_1_1_texture_gpu_manager.html#a24f8cd49c0990fb532306a1569b58f33", null ],
    [ "createOrRetrieveTexture", "class_ogre_1_1_texture_gpu_manager.html#a5643e2d490f3f305828e3de64e1b5934", null ],
    [ "createOrRetrieveTexture", "class_ogre_1_1_texture_gpu_manager.html#abf67202da75b8c6f9134d7e81baa89d8", null ],
    [ "createTexture", "class_ogre_1_1_texture_gpu_manager.html#a017eec4324d75ffb0de6b0fc1fdd2654", null ],
    [ "createTexture", "class_ogre_1_1_texture_gpu_manager.html#a8d1cdf54c1a262bc911d37235682ec1c", null ],
    [ "destroyAllAsyncTextureTicket", "class_ogre_1_1_texture_gpu_manager.html#a02832e2789d8fc68b4ce4586bad25010", null ],
    [ "destroyAsyncTextureTicket", "class_ogre_1_1_texture_gpu_manager.html#af906e6a5e055170b281a1986374b4754", null ],
    [ "destroyTexture", "class_ogre_1_1_texture_gpu_manager.html#a7dc898578da3113affb78ed60f209b71", null ],
    [ "dumpMemoryUsage", "class_ogre_1_1_texture_gpu_manager.html#a841f10a656bbd24ed92b87f616e33f74", null ],
    [ "dumpStats", "class_ogre_1_1_texture_gpu_manager.html#a0b0ab5ff277943748df853653efb8913", null ],
    [ "executeTask", "class_ogre_1_1_texture_gpu_manager.html#a400906a91ef0c5b7b61329de7872c91e", null ],
    [ "exportTextureMetadataCache", "class_ogre_1_1_texture_gpu_manager.html#a25ea160f5cd58eb1569743dee3bff9cc", null ],
    [ "findAliasNameStr", "class_ogre_1_1_texture_gpu_manager.html#abf7dedc19c2251a15643a3e240225abd", null ],
    [ "findResourceGroupStr", "class_ogre_1_1_texture_gpu_manager.html#abf7a7a36c00587fb8298f4100606c627", null ],
    [ "findResourceNameStr", "class_ogre_1_1_texture_gpu_manager.html#a45819a2f57371a1d5ae1d026a21510ab", null ],
    [ "findTextureNoThrow", "class_ogre_1_1_texture_gpu_manager.html#ad7aa5c6af459eb788ed985104c21f5f7", null ],
    [ "getBudget", "class_ogre_1_1_texture_gpu_manager.html#a5e938ff8fcf2cf1312e916b3b5078cfe", null ],
    [ "getDefaultMipmapGeneration", "class_ogre_1_1_texture_gpu_manager.html#af34d0779d8e031e998915b4528dbddb6", null ],
    [ "getDefaultMipmapGenerationCubemaps", "class_ogre_1_1_texture_gpu_manager.html#ace14aaadb7bf3b43b564c218186df62d", null ],
    [ "getEntries", "class_ogre_1_1_texture_gpu_manager.html#ab7806f6c350ad71d918f75a99fca84f0", null ],
    [ "getLoadRequestsCounter", "class_ogre_1_1_texture_gpu_manager.html#a0e9374e0a6a80f16ef5b3e95f38c2e44", null ],
    [ "getMemoryStats", "class_ogre_1_1_texture_gpu_manager.html#a3886c70b1674b192547c407edeb4c67e", null ],
    [ "getRenderSystem", "class_ogre_1_1_texture_gpu_manager.html#ad9f2c6ee08fce32295e93904e94d69fb", null ],
    [ "getStagingTexture", "class_ogre_1_1_texture_gpu_manager.html#a18f2ab9f38f0dbf29a75a82030231a9f", null ],
    [ "getVaoManager", "class_ogre_1_1_texture_gpu_manager.html#a9b7f3c063418bd31e284fd3dbd4f585e", null ],
    [ "hasPoolId", "class_ogre_1_1_texture_gpu_manager.html#a064b32e7db16917d223a729f3ce03a96", null ],
    [ "hasTextureResource", "class_ogre_1_1_texture_gpu_manager.html#ae7152f97e84cd44d73afc86d77951120", null ],
    [ "importTextureMetadataCache", "class_ogre_1_1_texture_gpu_manager.html#a423e53613f85ab74171ac4bb291c2555", null ],
    [ "isDoneStreaming", "class_ogre_1_1_texture_gpu_manager.html#aad2d1de6d372585cc4acfa16abae331c", null ],
    [ "notifyTextureChanged", "class_ogre_1_1_texture_gpu_manager.html#ab2012775609f389c5f205ee089a0c8b8", null ],
    [ "operator delete", "class_ogre_1_1_texture_gpu_manager.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
    [ "operator delete", "class_ogre_1_1_texture_gpu_manager.html#acb46d4b0a597156d9ba5abc39d127792", null ],
    [ "operator delete", "class_ogre_1_1_texture_gpu_manager.html#a1c727e879a260c37b00ce5505fe8e144", null ],
    [ "operator delete[]", "class_ogre_1_1_texture_gpu_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
    [ "operator delete[]", "class_ogre_1_1_texture_gpu_manager.html#a595ea4c05da8aa987d3800e65d23355d", null ],
    [ "operator new", "class_ogre_1_1_texture_gpu_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
    [ "operator new", "class_ogre_1_1_texture_gpu_manager.html#ab422c67a2c8844f410fe822a357cba3b", null ],
    [ "operator new", "class_ogre_1_1_texture_gpu_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
    [ "operator new[]", "class_ogre_1_1_texture_gpu_manager.html#adce32528577d71b228692df906ecd17c", null ],
    [ "operator new[]", "class_ogre_1_1_texture_gpu_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
    [ "removeStagingTexture", "class_ogre_1_1_texture_gpu_manager.html#a614a8c355b86c01d9f7b847b670c1cd3", null ],
    [ "reservePoolId", "class_ogre_1_1_texture_gpu_manager.html#a6e96132817c27bfae1c0374e98d20dfc", null ],
    [ "saveTexture", "class_ogre_1_1_texture_gpu_manager.html#a3796bc1de6a5a6efc208620686982b54", null ],
    [ "setDefaultMipmapGeneration", "class_ogre_1_1_texture_gpu_manager.html#abe21fe76416e68bcfc8fe57f2655e868", null ],
    [ "setStagingTextureMaxBudgetBytes", "class_ogre_1_1_texture_gpu_manager.html#a164a5285771064ccd10c8c2d9392d9da", null ],
    [ "setTextureGpuManagerListener", "class_ogre_1_1_texture_gpu_manager.html#af68751724984a25c311ca98459a739aa", null ],
    [ "setTrylockMutexFailureLimit", "class_ogre_1_1_texture_gpu_manager.html#a763c9420839cf914f7a5c1901c53539b", null ],
    [ "setWorkerThreadMaxPerStagingTextureRequestBytes", "class_ogre_1_1_texture_gpu_manager.html#aeb00a770d365459f490c2ecd9b96f025", null ],
    [ "setWorkerThreadMaxPreloadBytes", "class_ogre_1_1_texture_gpu_manager.html#a6de9d156bb0ef5a625f0f8a6f08a9b19", null ],
    [ "setWorkerThreadMinimumBudget", "class_ogre_1_1_texture_gpu_manager.html#ab9065d7ce750a69d07f0d315d623b2cc", null ],
    [ "shouldStayLoaded", "class_ogre_1_1_texture_gpu_manager.html#a1427f0b635a4186cd6083a9bab879fa2", null ],
    [ "shutdown", "class_ogre_1_1_texture_gpu_manager.html#a1188e251546ab3391ef646d60f2317d8", null ],
    [ "taskLoadToSysRamOrResident", "class_ogre_1_1_texture_gpu_manager.html#a0beb6964d2f52e28e852666257a30514", null ],
    [ "taskToUnloadOrDestroy", "class_ogre_1_1_texture_gpu_manager.html#a379578bf252f5fcf0c5168f0a88c2130", null ],
    [ "waitForStreamingCompletion", "class_ogre_1_1_texture_gpu_manager.html#abcf4123dc9b7b5242acac4bc1d9eef1a", null ],
    [ "mIgnoreSRgbPreference", "class_ogre_1_1_texture_gpu_manager.html#a1146a2b41f0f3f5d3b0b1bab1e74248d", null ]
];

==> ogre-next-3.0.0-2-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/class_ogre_1_1_texture_gpu_manager.js <==
var class_ogre_1_1_texture_gpu_manager =
[
    [ "BudgetEntry", "struct_ogre_1_1_texture_gpu_manager_1_1_budget_entry.html", "struct_ogre_1_1_texture_gpu_manager_1_1_budget_entry" ],
    [ "MetadataCacheEntry", "struct_ogre_1_1_texture_gpu_manager_1_1_metadata_cache_entry.html", "struct_ogre_1_1_texture_gpu_manager_1_1_metadata_cache_entry" ],
    [ "ResourceEntry", "struct_ogre_1_1_texture_gpu_manager_1_1_resource_entry.html", "struct_ogre_1_1_texture_gpu_manager_1_1_resource_entry" ],
    [ "BudgetEntryVec", "class_ogre_1_1_texture_gpu_manager.html#a243112239378b673ba9f1df5e7abdbf3", null ],
    [ "MetadataCacheMap", "class_ogre_1_1_texture_gpu_manager.html#a75e42d75a1eae1a28e52e4613832edb3", null ],
    [ "ResourceEntryMap", "class_ogre_1_1_texture_gpu_manager.html#ad657330e7020f561860d24366460271c", null ],
    [ "TextureGpuManager", "class_ogre_1_1_texture_gpu_manager.html#a7cc799aa12f7b03c686cec13d09d9c0b", null ],
    [ "~TextureGpuManager", "class_ogre_1_1_texture_gpu_manager.html#a8ea7a2892140d8d84ee8db3f6ea7aae4", null ],
    [ "_queueDownloadToRam", "class_ogre_1_1_texture_gpu_manager.html#a68dec5d2c3187c3d7be56d9c5cc55fc4", null ],
    [ "_releaseSlotFromTexture", "class_ogre_1_1_texture_gpu_manager.html#a89a4bb400a24d0e3ea9a9299192fa51d", null ],
    [ "_removeMetadataCacheEntry", "class_ogre_1_1_texture_gpu_manager.html#a38a3edb2437dae48c14a0d20c50877fa", null ],
    [ "_reserveSlotForTexture", "class_ogre_1_1_texture_gpu_manager.html#a93773f33d6018c991b4fa8c475a8a36d", null ],
    [ "_scheduleTransitionTo", "class_ogre_1_1_texture_gpu_manager.html#a57719d6bae200d39449eb5f98098b1c5", null ],
    [ "_scheduleUpdate", "class_ogre_1_1_texture_gpu_manager.html#a46f6c11e4af75070ada1e868e7b24412", null ],
    [ "_setIgnoreScheduledTasks", "class_ogre_1_1_texture_gpu_manager.html#ae905930e6b79e3a3c3152efc20d5249c", null ],
    [ "_update", "class_ogre_1_1_texture_gpu_manager.html#aa961b3aafc08805f7611d4edd283f804", null ],
    [ "_updateMetadataCache", "class_ogre_1_1_texture_gpu_manager.html#a4f6d7560d59263dc303563777b5c61e8", null ],
    [ "_updateStreaming", "class_ogre_1_1_texture_gpu_manager.html#a71b2dac622f85cd2dec83834ee10fecd", null ],
    [ "_updateStreamingWorkerThread", "class_ogre_1_1_texture_gpu_manager.html#a4f6ee50fe51ac71c60f66e044859bf9d", null ],
    [ "_updateTextureMultiLoadWorkerThread", "class_ogre_1_1_texture_gpu_manager.html#ada01fc57b26dd0f912572c288eb08dac", null ],
    [ "_waitFor", "class_ogre_1_1_texture_gpu_manager.html#a2c872d542fd78e2db884ff8904d4c39d", null ],
    [ "_waitForPendingGpuToCpuSyncs", "class_ogre_1_1_texture_gpu_manager.html#ac55e0672860ad3ed3695374d9e12c7ba", null ],
    [ "checkSupport", "class_ogre_1_1_texture_gpu_manager.html#ae4cace3a36dcc63cb0ba5662f2c29b8a", null ],
    [ "createAsyncTextureTicket", "class_ogre_1_1_texture_gpu_manager.html#a71e7ae62f823f48c7c4844a2d34589de", null ],
    [ "createOrRetrieveTexture", "class_ogre_1_1_texture_gpu_manager.html#ad118a876e3102b5ae6ba5cefba5bdf1d", null ],
    [ "createOrRetrieveTexture", "class_ogre_1_1_texture_gpu_manager.html#a24f8cd49c0990fb532306a1569b58f33", null ],
    [ "createOrRetrieveTexture", "class_ogre_1_1_texture_gpu_manager.html#a5643e2d490f3f305828e3de64e1b5934", null ],
    [ "createOrRetrieveTexture", "class_ogre_1_1_texture_gpu_manager.html#abf67202da75b8c6f9134d7e81baa89d8", null ],
    [ "createTexture", "class_ogre_1_1_texture_gpu_manager.html#a017eec4324d75ffb0de6b0fc1fdd2654", null ],
    [ "createTexture", "class_ogre_1_1_texture_gpu_manager.html#a8d1cdf54c1a262bc911d37235682ec1c", null ],
    [ "destroyAllAsyncTextureTicket", "class_ogre_1_1_texture_gpu_manager.html#a148bb602fcf5d9b37d38bb15eaff5944", null ],
    [ "destroyAsyncTextureTicket", "class_ogre_1_1_texture_gpu_manager.html#af906e6a5e055170b281a1986374b4754", null ],
    [ "destroyTexture", "class_ogre_1_1_texture_gpu_manager.html#a7dc898578da3113affb78ed60f209b71", null ],
    [ "dumpMemoryUsage", "class_ogre_1_1_texture_gpu_manager.html#a841f10a656bbd24ed92b87f616e33f74", null ],
    [ "dumpStats", "class_ogre_1_1_texture_gpu_manager.html#ab9f7904a44ab902755cd06ab73fe4c77", null ],
    [ "exportTextureMetadataCache", "class_ogre_1_1_texture_gpu_manager.html#a25ea160f5cd58eb1569743dee3bff9cc", null ],
    [ "findAliasNameStr", "class_ogre_1_1_texture_gpu_manager.html#abf7dedc19c2251a15643a3e240225abd", null ],
    [ "findResourceGroupStr", "class_ogre_1_1_texture_gpu_manager.html#abf7a7a36c00587fb8298f4100606c627", null ],
    [ "findResourceNameStr", "class_ogre_1_1_texture_gpu_manager.html#a45819a2f57371a1d5ae1d026a21510ab", null ],
    [ "findTextureNoThrow", "class_ogre_1_1_texture_gpu_manager.html#ad7aa5c6af459eb788ed985104c21f5f7", null ],
    [ "getBudget", "class_ogre_1_1_texture_gpu_manager.html#a7d68c04c2f29c8abc579dd3cb1788f0a", null ],
    [ "getDefaultMipmapGeneration", "class_ogre_1_1_texture_gpu_manager.html#a254afe8b84c3aceb91286e03f3d15bd6", null ],
    [ "getDefaultMipmapGenerationCubemaps", "class_ogre_1_1_texture_gpu_manager.html#a8fc903cc9c56854c0d0586dca2546cff", null ],
    [ "getEntries", "class_ogre_1_1_texture_gpu_manager.html#a0249d493bc5e78dc91e57a44a93c290e", null ],
    [ "getLoadRequestsCounter", "class_ogre_1_1_texture_gpu_manager.html#a0e9374e0a6a80f16ef5b3e95f38c2e44", null ],
    [ "getMemoryStats", "class_ogre_1_1_texture_gpu_manager.html#a3886c70b1674b192547c407edeb4c67e", null ],
    [ "getProfileLoadingTime", "class_ogre_1_1_texture_gpu_manager.html#a52d792552906d877cc26b4f0b725a126", null ],
    [ "getRenderSystem", "class_ogre_1_1_texture_gpu_manager.html#aba6d3b3e837106749a77009cc204a63c", null ],
    [ "getStagingTexture", "class_ogre_1_1_texture_gpu_manager.html#a18f2ab9f38f0dbf29a75a82030231a9f", null ],
    [ "getVaoManager", "class_ogre_1_1_texture_gpu_manager.html#ad520c068fa3e00e87b0267336ec749b9", null ],
    [ "hasPoolId", "class_ogre_1_1_texture_gpu_manager.html#a064b32e7db16917d223a729f3ce03a96", null ],
    [ "hasTextureResource", "class_ogre_1_1_texture_gpu_manager.html#ae7152f97e84cd44d73afc86d77951120", null ],
    [ "importTextureMetadataCache", "class_ogre_1_1_texture_gpu_manager.html#a423e53613f85ab74171ac4bb291c2555", null ],
    [ "isDoneStreaming", "class_ogre_1_1_texture_gpu_manager.html#aa7c61552db1bcabec430a34c6255fb05", null ],
    [ "notifyTextureChanged", "class_ogre_1_1_texture_gpu_manager.html#a251ca6ba922c656400b1c7ac7cac0fcd", null ],
    [ "removeStagingTexture", "class_ogre_1_1_texture_gpu_manager.html#a614a8c355b86c01d9f7b847b670c1cd3", null ],
    [ "reservePoolId", "class_ogre_1_1_texture_gpu_manager.html#a6e96132817c27bfae1c0374e98d20dfc", null ],
    [ "saveTexture", "class_ogre_1_1_texture_gpu_manager.html#a3796bc1de6a5a6efc208620686982b54", null ],
    [ "setDefaultMipmapGeneration", "class_ogre_1_1_texture_gpu_manager.html#abe21fe76416e68bcfc8fe57f2655e868", null ],
    [ "setMultiLoadPool", "class_ogre_1_1_texture_gpu_manager.html#a1ff9f8223324c7091eaa3698bd39efe2", null ],
    [ "setProfileLoadingTime", "class_ogre_1_1_texture_gpu_manager.html#a4e35f39923cc1f38d41c4f5fae52dcf9", null ],
    [ "setStagingTextureMaxBudgetBytes", "class_ogre_1_1_texture_gpu_manager.html#a164a5285771064ccd10c8c2d9392d9da", null ],
    [ "setTextureGpuManagerListener", "class_ogre_1_1_texture_gpu_manager.html#af68751724984a25c311ca98459a739aa", null ],
    [ "setTrylockMutexFailureLimit", "class_ogre_1_1_texture_gpu_manager.html#a763c9420839cf914f7a5c1901c53539b", null ],
    [ "setWorkerThreadMaxPerStagingTextureRequestBytes", "class_ogre_1_1_texture_gpu_manager.html#aeb00a770d365459f490c2ecd9b96f025", null ],
    [ "setWorkerThreadMaxPreloadBytes", "class_ogre_1_1_texture_gpu_manager.html#a6de9d156bb0ef5a625f0f8a6f08a9b19", null ],
    [ "setWorkerThreadMinimumBudget", "class_ogre_1_1_texture_gpu_manager.html#a40cd14ba1ba374c0bf5d0774a79b1290", null ],
    [ "shutdown", "class_ogre_1_1_texture_gpu_manager.html#a1188e251546ab3391ef646d60f2317d8", null ],
    [ "waitForStreamingCompletion", "class_ogre_1_1_texture_gpu_manager.html#a34ac834c93bbe00900232169bd8b3b53", null ],
    [ "mIgnoreSRgbPreference", "class_ogre_1_1_texture_gpu_manager.html#a1146a2b41f0f3f5d3b0b1bab1e74248d", null ]
];
